@@ -1,28 +1,30 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Commercial License Agreement provided with the
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Nokia.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
@@ -33,8 +35,6 @@
 ** ensure the GNU General Public License version 3.0 requirements will be
 ** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -48,6 +48,8 @@
 #include <QMouseEvent>
 #include <qmath.h>
 
+const int animationInterval = 15; // update every 16 ms = ~60FPS
+
 CompositionWidget::CompositionWidget(QWidget *parent)
     : QWidget(parent)
 {
@@ -236,6 +238,7 @@ CompositionRenderer::CompositionRenderer(QWidget *parent)
     : ArthurFrame(parent)
 {
     m_animation_enabled = true;
+    m_animationTimer = startTimer(animationInterval);
 #ifdef Q_WS_QWS
     m_image = QPixmap(":res/composition/flower.jpg");
     m_image.setAlphaChannel(QPixmap(":res/composition/flower_alpha.jpg"));
@@ -264,6 +267,20 @@ QRectF rectangle_around(const QPointF &p, const QSizeF &size = QSize(250, 200))
     return rect;
 }
 
+void CompositionRenderer::setAnimationEnabled(bool enabled)
+{
+    if (m_animation_enabled == enabled)
+        return;
+    m_animation_enabled = enabled;
+    if (enabled) {
+        Q_ASSERT(!m_animationTimer);
+        m_animationTimer = startTimer(animationInterval);
+    } else {
+        killTimer(m_animationTimer);
+        m_animationTimer = 0;
+    }
+}
+
 void CompositionRenderer::updateCirclePos()
 {
     if (m_current_object != NoObject)
@@ -377,7 +394,9 @@ void CompositionRenderer::paint(QPainter *painter)
             p.setCompositionMode(QPainter::CompositionMode_Source);
             p.fillRect(QRect(0, 0, m_pbuffer->width(), m_pbuffer->height()), Qt::transparent);
 
-            p.save();
+            p.save(); // Needed when using the GL1 engine
+            p.beginNativePainting(); // Needed when using the GL2 engine
+
             glBindTexture(GL_TEXTURE_2D, m_base_tex);
             glEnable(GL_TEXTURE_2D);
             glColor4f(1.,1.,1.,1.);
@@ -399,16 +418,21 @@ void CompositionRenderer::paint(QPainter *painter)
             glEnd();
 
             glDisable(GL_TEXTURE_2D);
-            p.restore();
+
+            p.endNativePainting(); // Needed when using the GL2 engine
+            p.restore(); // Needed when using the GL1 engine
 
             drawSource(p);
             p.end();
             m_pbuffer->updateDynamicTexture(m_compositing_tex);
         }
 
-        glWidget()->makeCurrent();
+        painter->beginNativePainting(); // Needed when using the GL2 engine
+        glWidget()->makeCurrent(); // Needed when using the GL1 engine
         glBindTexture(GL_TEXTURE_2D, m_compositing_tex);
         glEnable(GL_TEXTURE_2D);
+        glEnable(GL_BLEND);
+        glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
         glColor4f(1.,1.,1.,1.);
         glBegin(GL_QUADS);
         {
@@ -426,6 +450,7 @@ void CompositionRenderer::paint(QPainter *painter)
         }
         glEnd();
         glDisable(GL_TEXTURE_2D);
+        painter->endNativePainting(); // Needed when using the GL2 engine
     } else
 #endif
     {
@@ -449,7 +474,7 @@ void CompositionRenderer::paint(QPainter *painter)
 #ifdef Q_WS_QWS
         m_buffer = m_base_buffer;
 #else
-        memcpy(m_buffer.bits(), m_base_buffer.bits(), m_buffer.numBytes());
+        memcpy(m_buffer.bits(), m_base_buffer.bits(), m_buffer.byteCount());
 #endif
 
         {
@@ -463,10 +488,6 @@ void CompositionRenderer::paint(QPainter *painter)
         painter->drawImage(0, 0, m_buffer);
 #endif
     }
-
-    if (m_animation_enabled && m_current_object == NoObject) {
-        updateCirclePos();
-    }
 }
 
 void CompositionRenderer::mousePressEvent(QMouseEvent *e)
@@ -481,6 +502,10 @@ void CompositionRenderer::mousePressEvent(QMouseEvent *e)
     } else {
         m_current_object = NoObject;
     }
+    if (m_animation_enabled) {
+        killTimer(m_animationTimer);
+        m_animationTimer = 0;
+    }
 }
 
 void CompositionRenderer::mouseMoveEvent(QMouseEvent *e)
@@ -492,7 +517,15 @@ void CompositionRenderer::mouseReleaseEvent(QMouseEvent *)
 {
     m_current_object = NoObject;
 
-    if (m_animation_enabled)
+    if (m_animation_enabled) {
+        Q_ASSERT(!m_animationTimer);
+        m_animationTimer = startTimer(animationInterval);
+    }
+}
+
+void CompositionRenderer::timerEvent(QTimerEvent *event)
+{
+    if (event->timerId() == m_animationTimer)
         updateCirclePos();
 }
 
