@@ -1,8 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
@@ -18,10 +17,10 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
-**     the names of its contributors may be used to endorse or promote
-**     products derived from this software without specific prior written
-**     permission.
+**   * Neither the name of The Qt Company Ltd nor the names of its
+**     contributors may be used to endorse or promote products derived
+**     from this software without specific prior written permission.
+**
 **
 ** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 ** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -34,6 +33,7 @@
 ** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 ** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 ** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
+**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -65,13 +65,13 @@ SettingsDialog::SettingsDialog(
     QAudioDeviceInfo device;
     foreach (device, availableInputDevices)
         m_inputDeviceComboBox->addItem(device.deviceName(),
-                                       qVariantFromValue(device));
+                                       QVariant::fromValue(device));
     foreach (device, availableOutputDevices)
         m_outputDeviceComboBox->addItem(device.deviceName(),
-                                       qVariantFromValue(device));
+                                       QVariant::fromValue(device));
 
-    m_windowFunctionComboBox->addItem(tr("None"), qVariantFromValue(int(NoWindow)));
-    m_windowFunctionComboBox->addItem("Hann", qVariantFromValue(int(HannWindow)));
+    m_windowFunctionComboBox->addItem(tr("None"), QVariant::fromValue(int(NoWindow)));
+    m_windowFunctionComboBox->addItem("Hann", QVariant::fromValue(int(HannWindow)));
     m_windowFunctionComboBox->setCurrentIndex(m_windowFunction);
 
     // Initialize default devices
