@@ -1,40 +1,39 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Commercial License Agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Nokia.
+** $QT_BEGIN_LICENSE:BSD$
+** You may use this file under the terms of the BSD license as follows:
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** "Redistribution and use in source and binary forms, with or without
+** modification, are permitted provided that the following conditions are
+** met:
+**   * Redistributions of source code must retain the above copyright
+**     notice, this list of conditions and the following disclaimer.
+**   * Redistributions in binary form must reproduce the above copyright
+**     notice, this list of conditions and the following disclaimer in
+**     the documentation and/or other materials provided with the
+**     distribution.
+**   * Neither the name of The Qt Company Ltd nor the names of its
+**     contributors may be used to endorse or promote products derived
+**     from this software without specific prior written permission.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -48,9 +47,6 @@ Window::Window()
     proxyModel = new QSortFilterProxyModel;
     proxyModel->setDynamicSortFilter(true);
 
-    sourceGroupBox = new QGroupBox(tr("Original Model"));
-    proxyGroupBox = new QGroupBox(tr("Sorted/Filtered Model"));
-
     sourceView = new QTreeView;
     sourceView->setRootIsDecorated(false);
     sourceView->setAlternatingRowColors(true);
@@ -82,7 +78,7 @@ Window::Window()
     filterColumnLabel = new QLabel(tr("Filter &column:"));
     filterColumnLabel->setBuddy(filterColumnComboBox);
 
-    connect(filterPatternLineEdit, SIGNAL(textChanged(const QString &)),
+    connect(filterPatternLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(filterRegExpChanged()));
     connect(filterSyntaxComboBox, SIGNAL(currentIndexChanged(int)),
             this, SLOT(filterRegExpChanged()));
@@ -93,6 +89,41 @@ Window::Window()
     connect(sortCaseSensitivityCheckBox, SIGNAL(toggled(bool)),
             this, SLOT(sortChanged()));
 
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_WS_SIMULATOR)
+    sourceWidget = new QWidget;
+    filterWidget = new QWidget;
+    proxyWidget = new QWidget;
+
+    QHBoxLayout *sourceLayout = new QHBoxLayout;
+    sourceLayout->addWidget(sourceView);
+    sourceWidget->setLayout(sourceLayout);
+
+    QGridLayout *filterLayout = new QGridLayout;
+    filterLayout->addWidget(filterPatternLabel, 1, 0);
+    filterLayout->addWidget(filterPatternLineEdit, 1, 1, 1, 2);
+    filterLayout->addWidget(filterSyntaxLabel, 2, 0);
+    filterLayout->addWidget(filterSyntaxComboBox, 2, 1, 1, 2);
+    filterLayout->addWidget(filterColumnLabel, 3, 0);
+    filterLayout->addWidget(filterColumnComboBox, 3, 1, 1, 2);
+    filterLayout->addWidget(filterCaseSensitivityCheckBox, 4, 0, 1, 2);
+    filterLayout->addWidget(sortCaseSensitivityCheckBox, 4, 2);
+    filterWidget->setLayout(filterLayout);
+
+    QHBoxLayout *proxyLayout = new QHBoxLayout;
+    proxyLayout->addWidget(proxyView);
+    proxyWidget->setLayout(proxyLayout);
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+
+    QTabWidget *tabWidget = new QTabWidget;
+    tabWidget->addTab(sourceWidget, "Source");
+    tabWidget->addTab(filterWidget, "Filters");
+    tabWidget->addTab(proxyWidget, "Proxy");
+    mainLayout->addWidget(tabWidget);
+#else
+    sourceGroupBox = new QGroupBox(tr("Original Model"));
+    proxyGroupBox = new QGroupBox(tr("Sorted/Filtered Model"));
+
     QHBoxLayout *sourceLayout = new QHBoxLayout;
     sourceLayout->addWidget(sourceView);
     sourceGroupBox->setLayout(sourceLayout);
@@ -110,8 +141,11 @@ Window::Window()
     proxyGroupBox->setLayout(proxyLayout);
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
+
     mainLayout->addWidget(sourceGroupBox);
     mainLayout->addWidget(proxyGroupBox);
+#endif
+
     setLayout(mainLayout);
 
     setWindowTitle(tr("Basic Sort/Filter Model"));
