@@ -1,8 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
@@ -18,10 +17,10 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
-**     the names of its contributors may be used to endorse or promote
-**     products derived from this software without specific prior written
-**     permission.
+**   * Neither the name of The Qt Company Ltd nor the names of its
+**     contributors may be used to endorse or promote products derived
+**     from this software without specific prior written permission.
+**
 **
 ** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 ** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -34,6 +33,7 @@
 ** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 ** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 ** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
+**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -52,16 +52,23 @@ void initializeModel(QSqlQueryModel *model)
     model->setHeaderData(2, Qt::Horizontal, QObject::tr("Last name"));
 }
 
-void createView(const QString &title, QSqlQueryModel *model)
+QTableView* createView(QSqlQueryModel *model, const QString &title = "")
 {
-    static int offset = 0;
-
     QTableView *view = new QTableView;
     view->setModel(model);
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_WS_SIMULATOR)
+    Q_UNUSED(title);
+    view->resizeColumnsToContents();
+#else
+    static int offset = 0;
+
     view->setWindowTitle(title);
     view->move(100 + offset, 100 + offset);
     offset += 20;
     view->show();
+#endif
+
+    return view;
 }
 
 int main(int argc, char *argv[])
@@ -78,9 +85,17 @@ int main(int argc, char *argv[])
     initializeModel(&editableModel);
     initializeModel(&customModel);
 
-    createView(QObject::tr("Plain Query Model"), &plainModel);
-    createView(QObject::tr("Editable Query Model"), &editableModel);
-    createView(QObject::tr("Custom Query Model"), &customModel);
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_WS_SIMULATOR)
+    QTabWidget *tabWidget = new QTabWidget;
+    tabWidget->addTab(createView(&plainModel), QObject::tr("Plain"));
+    tabWidget->addTab(createView(&editableModel), QObject::tr("Editable"));
+    tabWidget->addTab(createView(&customModel), QObject::tr("Custom"));
+    tabWidget->showMaximized();
+#else
+    createView(&plainModel, QObject::tr("Plain Query Model"));
+    createView(&editableModel, QObject::tr("Editable Query Model"));
+    createView(&customModel, QObject::tr("Custom Query Model"));
+#endif
 
     return app.exec();
 }
