@@ -1,8 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
@@ -18,10 +17,10 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
-**     the names of its contributors may be used to endorse or promote
-**     products derived from this software without specific prior written
-**     permission.
+**   * Neither the name of The Qt Company Ltd nor the names of its
+**     contributors may be used to endorse or promote products derived
+**     from this software without specific prior written permission.
+**
 **
 ** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 ** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -34,6 +33,7 @@
 ** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 ** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 ** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
+**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -43,9 +43,35 @@
 
 #include <QPixmap>
 #include <QWidget>
-
 #include "renderthread.h"
 
+#if defined(Q_WS_S60) || defined(Q_WS_MAEMO_5) || defined(Q_WS_SIMULATOR)
+#include <QPushButton>
+
+class ZoomButton : public QPushButton
+{
+    Q_OBJECT
+public:
+    ZoomButton(const QString &text, double zoomFactor, QWidget *parent = NULL)
+        : QPushButton(text, parent), m_ZoomFactor(zoomFactor)
+    {
+        connect(this, SIGNAL(clicked()), this, SLOT(handleClick()));
+    }
+
+signals:
+    void zoom(double zoomFactor);
+
+private slots:
+    void handleClick()
+    {
+        emit zoom(m_ZoomFactor);
+    }
+
+private:
+    const double m_ZoomFactor;
+};
+#endif
+
 //! [0]
 class MandelbrotWidget : public QWidget
 {
@@ -65,9 +91,9 @@ protected:
 
 private slots:
     void updatePixmap(const QImage &image, double scaleFactor);
+    void zoom(double zoomFactor);
 
 private:
-    void zoom(double zoomFactor);
     void scroll(int deltaX, int deltaY);
 
     RenderThread thread;
